#!/bin/sh -efu
# ***** BEGIN LICENSE BLOCK *****
# * Copyright (C) 2007  Alexey Gladkov <legion@altlinux.org>
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
# ***** END LICENSE BLOCK *****

. install2-init-functions

append_fstab() {
	local src="$1"; shift
	local dst="$1"; shift

	mountpoint -q "$src" || return 0

	mkdir -p -- "$destdir/$dst"
	fgrep " $src " /proc/mounts |
		sed -e "s# $src # $dst #" \
		    -e 's#,addr=[^, ]\+##' >> "$destdir/etc/fstab"
}

sources_list() {
	local url="$1";shift;
	local comps="$1";shift;

	mkdir -p -- "$destdir/etc/apt/sources.list.d"
	printf 'rpm %s ALTLinux %s\n' "$url" "${comps% }" > "$destdir/etc/apt/sources.list.d/sources.installer.list"
}

mount --bind "/dev" "$destdir/dev"
mount --bind "/dev/pts" "$destdir/dev/pts"
mount --bind "/proc" "$destdir/proc"
mount --bind "/sys" "$destdir/sys"

if [ -d /tmp/alterator ];then
    mkdir -p -- "$destdir/tmp/alterator"
    mount --bind /tmp/alterator "$destdir/tmp/alterator"
fi

src_mpoint=
dst_mpoint=
case "$METHOD" in
	cdrom)
		src_mpoint="$image_dir"
		dst_mpoint="$destdir/$cdrom_stage3"
		;;
	disk|nfs)
		src_mpoint="$image_dir"
		dst_mpoint="$destdir/mnt/disk"
		comps="$(find "$image_dir"/ALTLinux \
			    -mindepth 1 -maxdepth 1 -type d -name 'RPMS.*' -printf '%f\n' |
			    sed -e 's/^RPMS\.//' |
			    tr '\n' ' ')"

		sources_list "file:/mnt/disk" "$comps"

		# Save mountpoint
		append_fstab "$src_mpoint" "/mnt/disk"
		;;
	http|ftp)
		sources_list "$METHOD://$HOST$PREFIX" "base disk"
		;;
esac

[ -z "$dst_mpoint" ] || mkdir -p -- "$dst_mpoint"
[ -z "$src_mpoint" -o -z "$dst_mpoint" ] || mount --bind "$src_mpoint" "$dst_mpoint"
